@@ -4,7 +4,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2016	PgPool Global Development Group
+ * Copyright (c) 2003-2011	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -25,8 +25,7 @@
 
 #ifndef LIBPCP_EXT_H
 #define LIBPCP_EXT_H
-#include <signal.h>
-#include <stdio.h>
+
 /*
  * startup packet definitions (v2) stolen from PostgreSQL
  */
@@ -63,12 +62,7 @@ typedef struct {
 } BackendInfo;
 
 typedef struct {
-	sig_atomic_t num_backends;		/* Number of used PostgreSQL backends.
-									 * This needs to be a sig_atomic_t type
-									 * since it is replaced by a local
-									 * variable while reloading pgpool.conf.
-									 */
-
+	int num_backends;		/* number of used PostgreSQL backends */
 	BackendInfo backend_info[MAX_NUM_BACKENDS];
 } BackendDesc;
 /*
@@ -166,9 +160,10 @@ typedef struct {
  * reporting types
  */
 /* some length definitions */
+#define POOLCONFIG_MAXIDLEN 4
 #define POOLCONFIG_MAXNAMELEN 64
 #define POOLCONFIG_MAXVALLEN 512
-#define POOLCONFIG_MAXDESCLEN 80
+#define POOLCONFIG_MAXDESCLEN 64
 #define POOLCONFIG_MAXIDENTLEN 63
 #define POOLCONFIG_MAXPORTLEN 6
 #define POOLCONFIG_MAXSTATLEN 2
@@ -185,11 +180,12 @@ typedef struct {
 
 /* nodes report struct */
 typedef struct {
-	char node_id[POOLCONFIG_MAXSTATLEN+1];
-	char hostname[MAX_DB_HOST_NAMELEN+1];
-	char port[POOLCONFIG_MAXIDENTLEN+1];
+	char node_id[POOLCONFIG_MAXIDLEN+1];
+	char hostname[POOLCONFIG_MAXIDENTLEN+1];
+	char port[POOLCONFIG_MAXPORTLEN+1];
 	char status[POOLCONFIG_MAXSTATLEN+1];
 	char lb_weight[POOLCONFIG_MAXWEIGHTLEN+1];
+	char role[POOLCONFIG_MAXWEIGHTLEN+1];
 } POOL_REPORT_NODES;
 
 /* processes report struct */
