@@ -40,6 +40,7 @@ int wd_IP_up(void);
 int wd_IP_down(void);
 int wd_get_cmd(char * buf, char * cmd);
 static int exec_ifconfig(char * path,char * command);
+char *string_replace(const char *string, const char *pattern, const char *replacement);
 
 int
 wd_IP_up(void)
@@ -128,7 +129,7 @@ exec_ifconfig(char * path,char * command)
 	int status;
 	char * args[24];
 	int pid, i = 0;
-	char buf[256];
+	char* buf;
 	char *bp, *ep;
 
 	if (pipe(pfd) == -1)
@@ -136,8 +137,9 @@ exec_ifconfig(char * path,char * command)
 		pool_error("exec_ifconfig: pipe open error:%s",strerror(errno));
 		return WD_NG;
 	}
-	memset(buf,0,sizeof(buf));
-	strlcpy(buf,command,sizeof(buf));
+
+	buf = string_replace(command,"$_IP_$",pool_config->delegate_IP);
+
 	bp = buf;
 	while (*bp == ' ')
 	{
@@ -150,14 +152,7 @@ exec_ifconfig(char * path,char * command)
 		{
 			*ep = '\0';
 		}
-		if (!strncmp(bp,"$_IP_$",5))
-		{
-			args[i++] = pool_config->delegate_IP;
-		}
-		else
-		{
-			args[i++] = bp;
-		}
+		args[i++] = bp;
 		if (ep != NULL)
 		{
 			bp = ep +1;
@@ -184,6 +179,7 @@ exec_ifconfig(char * path,char * command)
 	}
 	else
 	{
+		free(buf);
 		close(pfd[1]);
 		for (;;)
 		{
@@ -206,4 +202,44 @@ exec_ifconfig(char * path,char * command)
 	return WD_OK;
 }
 
+/*
+ * string_replace()
+ * returns the new malloced string after replacing all
+ * occurances of pattern in string with replacement string
+ */
+char *
+string_replace(const char *string, const char *pattern, const char *replacement)
+{
+	char *tok = NULL;
+	char *newstr = NULL;
+	char *oldstr = NULL;
+	char *head = NULL;
+	size_t pat_len,rep_len;
+
+	newstr = strdup(string);
+	/* bail out if no pattern or replacement is given */
+	if ( pattern == NULL || replacement == NULL )
+		return newstr;
+
+	pat_len = strlen(pattern);
+	rep_len = strlen(replacement);
+
+	head = newstr;
+	while ( (tok = strstr(head,pattern)))
+	{
+		oldstr = newstr;
+		newstr = malloc ( strlen ( oldstr ) - pat_len + rep_len + 1 );
+
+		memcpy(newstr, oldstr, tok - oldstr );
+		memcpy(newstr + (tok - oldstr), replacement, rep_len );
+		memcpy(newstr + (tok - oldstr) + rep_len, tok + pat_len, strlen(oldstr) - pat_len - (tok - oldstr));
+		/* put the string terminator */
+		memset( newstr + strlen (oldstr) - pat_len + rep_len , 0, 1 );
+		/* move back head right after the last replacement */
+		head = newstr + (tok - oldstr) + rep_len;
+		free(oldstr);
+	}
+	return newstr;
+}
+
 
